@@ -4,16 +4,17 @@ use warnings;
 no strict   'refs';
 no warnings 'once';
 
-require DBIx::DataModel::Meta;
-require DBIx::DataModel::Meta::Utils;
-require DBIx::DataModel::Meta::Schema;
-require DBIx::DataModel::Meta::Source;
-require DBIx::DataModel::Schema;
-require DBIx::DataModel::Source;
-require DBIx::DataModel::Source::Table;
-require DBIx::DataModel::Statement;
-require DBIx::DataModel::Statement::JDBC;
-require SQL::Abstract::More;
+use DBIx::DataModel::ConnectedSource;
+use DBIx::DataModel::Meta;
+use DBIx::DataModel::Meta::Schema;
+use DBIx::DataModel::Meta::Source;
+use DBIx::DataModel::Meta::Utils;
+use DBIx::DataModel::Schema;
+use DBIx::DataModel::Source;
+use DBIx::DataModel::Source::Table;
+use DBIx::DataModel::Statement;
+use DBIx::DataModel::Statement::JDBC;
+use SQL::Abstract::More;
 
 my $tmp; # used for various renaming loops
 
@@ -44,20 +45,18 @@ my $orig_Schema = \&Schema;
   # convert args received as camelCase
   DBIx::DataModel::Compatibility::V1::_rename_camelCase_keys(\%args);
 
-  # extract args that should go to Source::Schema and not Meta::Source::Schema
+  # extract args that should go to DBIDM::Schema and not DBIDM::Meta::Schema
   my %singleton_args;
   foreach my $key (qw/dbh debug  dbi_prepare_method
                       sql_abstract sql_dialect/) {
     $tmp = delete $args{$key} and $singleton_args{$key} = $tmp;
   }
 
-
-  # now view_parent is just like table_parent
+  # view_parent is now join_parent (not 100% correct, but the best we can do)
   if (my $vp = delete $args{view_parent}) {
-    $vp = [$vp] unless ref $vp;
-    $args{table_parent} ||= [];
-    $args{table_parent} = [$args{table_parent}] unless ref $args{table_parent};
-    push @{$args{table_parent}}, @$vp;
+    $args{join_parent} ||= [];
+    $args{join_parent} = [$args{join_parent}] unless ref $args{join_parent};
+    push @{$args{join_parent}}, @$vp;
   }
 
   # create the Meta::Schema
@@ -107,6 +106,18 @@ my $orig_Schema = \&Schema;
 
 
 
+#----------------------------------------------------------------------
+package DBIx::DataModel::ConnectedSource;
+#----------------------------------------------------------------------
+use strict;
+use warnings;
+
+sub ColumnType {
+  my ($self, $typeName, @args) = @_;
+  $self->{meta_source}->define_column_type($typeName, @args);
+}
+
+
 #----------------------------------------------------------------------
 package DBIx::DataModel::Meta::Schema;
 #----------------------------------------------------------------------
@@ -256,9 +267,6 @@ sub createStatement {
   return $class->select(@_, -resultAs => 'statement');
 }
 
-
-
-
 sub selectImplicitlyFor {
   my $self = shift;
 
@@ -268,7 +276,6 @@ sub selectImplicitlyFor {
   $self->metadm->schema->class->select_implicitly_for(@_);
 }
 
-
 sub _autoloader {
   my $self = shift;
   my $class = ref($self) || $self;
@@ -429,14 +436,6 @@ my $orig_refine = \&refine;
 *{pageBoundaries} = \&page_boundaries;
 *{pageRows}       = \&page_rows;
 
-sub ColumnType {
-  my ($self, $typeName, @args) = @_;
-  $self->{meta_source}->define_column_type($typeName, @args);
-}
-
-
-
-
 #----------------------------------------------------------------------
 package DBIx::DataModel::Statement::JDBC;
 #----------------------------------------------------------------------
@@ -451,7 +450,7 @@ use Carp;
 # simulate previous classes, now moved into the Source:: namespace, so that
 # they can be inherited from
 #----------------------------------------------------------------------
-package DBIx::DataModel::Table; 
+package DBIx::DataModel::Table;
 #----------------------------------------------------------------------
 $INC{"DBIx/DataModel/Table.pm"} = 1;
 our @ISA = qw/DBIx::DataModel::Source::Table/;
